pub mod animation;
pub mod bind;
pub mod buffer;
pub mod command;
pub mod completion;
pub mod component;
pub mod decoration;
pub mod display;
pub mod event_bus;
pub mod frame;
pub mod keystroke;
pub mod rpc;
pub mod visibility;
pub mod visual;

/// Re-export `reovim_sys` for plugin access to low-level types (Color, etc.)
pub use reovim_sys as sys;
pub mod command_line;
pub mod compositor;
pub mod config;
pub mod constants;
pub mod content;
pub mod context_provider;
pub mod event;
pub mod filetype;
pub mod folding;
pub mod highlight;
pub mod indent;
pub mod interactor;
pub mod io;
pub mod jumplist;
pub mod landing;
pub mod modd;
pub mod modifier;
pub mod motion;
pub mod option;
pub mod plugin;
pub mod register;
pub mod render;
pub mod runtime;
pub mod screen;
pub mod settings;
pub mod sign;
// settings_menu is now a standalone plugin: reovim-plugin-settings-menu
pub mod style;
pub mod syntax;
pub mod testing;
pub mod textobject;
pub mod types;
pub mod ui;
